@@ -21,6 +21,9 @@ STORAGE_COST = PLUGIN_SETTINGS.get('storage_cost', '')
 memory_validator = RegexValidator(r"[1-9][0-9]*(Mi|Gi)$", "The input should contain only positive Number, which ends "
                                                           "with Mi (Megabyte) or Gi (Gigabyte)")
 
+project_name_validator = RegexValidator(r"[1-9][0-9]*(Mi|Gi)$", "The input should contain only positive Number, which "
+                                                                "ends with Mi (Megabyte) or Gi (Gigabyte)")
+
 
 class OCPProject(NetBoxModel):
     name = CharField(
@@ -38,16 +41,11 @@ class OCPProject(NetBoxModel):
         verbose_name="Display name",
         help_text="Display Name of the project e.g. Web Shop Shopify"
     )
-    owner = ForeignKey(
+    project_owner = ForeignKey(
         to='tenancy.Contact',
         on_delete=PROTECT,
         related_name='ocp_project_owner',
     )
-    contact = ForeignKey(
-        to='tenancy.Contact',
-        on_delete=PROTECT,
-        related_name='ocp_project_contact',
-    )
     customer = ForeignKey(
         to='tenancy.Tenant',
         on_delete=PROTECT,
@@ -69,12 +67,12 @@ class OCPProject(NetBoxModel):
         help_text="The jira request id e.g. TICKET1234",
     )
 
-    clone_fields = ["name", "description", "display_name", "owner", "contact", "customer", "docu_url", "workload",
+    clone_fields = ["name", "description", "display_name", "owner", "customer", "docu_url", "workload",
                     "request"]
 
     class Meta:
         verbose_name = "OCP Project"
-        ordering = ["name", "description", "display_name", "owner", "contact", "customer", "docu_url", "workload",
+        ordering = ["name", "description", "display_name", "owner", "customer", "docu_url", "workload",
                     "request"]
 
     def __str__(self):
@@ -94,20 +92,20 @@ class OCPProject(NetBoxModel):
         count_assignment = ContactAssignment.objects.filter(object_id=self.pk).count()
         if count_assignment == 0:
             ContactAssignment.objects.create(object_id=self.pk,
-                                             contact_id=self.contact.pk,
+                                             contact_id=self.project_owner.pk,
                                              content_type_id=ocp_project_type_pk,
                                              role_id=project_owner_pk)
         else:
             current_assignment = ContactAssignment.objects.get(object_id=self.pk, content_type_id=ocp_project_type_pk)
             print(current_assignment.contact)
-            print(self.contact)
+            print(self.project_owner)
             print(*args)
             print(**kwargs)
-            if current_assignment.contact == self.contact:
+            if current_assignment.contact == self.project_owner:
                 print("Nothing changed in assignment")
             else:
                 print("something changed in assignment")
-                current_assignment.contact = self.contact
+                current_assignment.contact = self.project_owner
                 current_assignment.save()
         super(OCPProject, self).save(*args, **kwargs)
 
@@ -117,8 +115,8 @@ class OCPProject(NetBoxModel):
             'description': self.description,
             'displayName': self.display_name,
             'customer': self.customer.name,
-            'owner': self.owner.name,
-            'contact': self.contact.name,
+            'owner': self.project_owner.name,
+            'contact': self.project_owner.email,
             'workloads': self.workload,
             'request': self.request,
             'url': self.docu_url,
